.. image:: https://travis-ci.org/colour-science/colour.svg?branch=master
    :target: https://travis-ci.org/colour-science/colour
.. image:: https://coveralls.io/repos/colour-science/colour/badge.png?branch=master
    :target: https://coveralls.io/r/colour-science/colour?branch=master
.. image:: https://landscape.io/github/colour-science/colour/master/landscape.png
    :target: https://landscape.io/github/colour-science/colour/master
    :alt: Code Health
..  image:: https://gemnasium.com/colour-science/colour.png
    :target: https://gemnasium.com/KelSolaar/TravisRamblings
    :alt: Dependency Status
.. image:: https://badge.waffle.io/colour-science/colour.svg?label=ready&title=Ready
    :target: https://waffle.io/colour-science/colour
    :alt: 'Stories in Ready'

Colour Science for Python
=========================

..  image:: https://raw.githubusercontent.com/colour-science/colour-branding/master/images/Colour_Logo_Medium_001.png

`Colour <https://github.com/colour-science/colour>`_ is a `Python <https://www.python.org/>`_ colour science package implementing a comprehensive number of colour theory transformations and algorithms.

It is open source and freely available and under the `New BSD License <http://opensource.org/licenses/BSD-3-Clause>`_ terms.

Features
--------

`Colour <https://github.com/colour-science/colour>`_ features a rich dataset and collection of objects, please see the `highlights <http://colour-science.org/features.php>`_ page for more information.

Installation
------------

The installation procedure is described in the `Installation Guide <http://colour-science.org/installation.php>`_.

Usage
-----

The two main references for `Colour <https://github.com/colour-science/colour>`_ usage are the complete sphinx `API Reference <http://colour-science.org/api/latest/html/index.html>`_ and the `IPython Notebooks <http://nbviewer.ipython.org/github/colour-science/colour-ipython/blob/master/notebooks/colour.ipynb>`_ with detailed historical and theoretical context and images:

-   `API Reference <http://colour-science.org/api/latest/html/index.html>`_
-   `IPython Notebooks <http://nbviewer.ipython.org/github/colour-science/colour-ipython/blob/master/notebooks/colour.ipynb>`_

Contributing
------------

If you would like to contribute to `Colour <https://github.com/colour-science/colour>`_, please refer to the following `contributing <http://colour-science.org/contributing.php>`_ guide.

Changes
-------

The changes are viewable on the `releases <https://github.com/colour-science/colour/releases>`_ page.

About
-----

| **Colour** by Colour Developers - 2013 - 2014
| Copyright © 2013 - 2014 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour <http://github.com/colour-science/colour>`_
